# SC-VAR

Here we report a human variants interpreter, named SC-VAR. 


# What can sc-var do?

This tool can interpret disease-related risks with whole genome wide (including both coding and non-coding regions) variants from GWAS studies and single-cell data on four layers: risk CREs,risk genes, gene sets, and cell types.




# How to install?

pip install sc-var







## About



![Fig1](https://github.com/user-attachments/assets/ccb0e726-225b-4cfa-a71e-2714c92c76b9)






## Usage

Check https://github.com/gefeiZ/sc_var/tree/main/Vignettes for details



Data request: 

Single cell data &

Peak co-accessibility Data or Peak to gene linkage Data (which could obtained from single cell data using cicero or signac) &

GWAS data 

